@@ -1,23 +1,46 @@
+"""BOC module methods"""
 from typing import Union, Awaitable
 
 from tonclient.module import TonModule
-from tonclient.types import ParamsOfParse, ResultOfParse, \
-    ParamsOfParseShardstate, ParamsOfGetBocHash, ResultOfGetBocHash, \
-    ParamsOfGetBlockchainConfig, ResultOfGetBlockchainConfig, \
-    ParamsOfGetCodeFromTvc, ResultOfGetCodeFromTvc, ParamsOfBocCacheGet, \
-    ResultOfBocCacheGet, ParamsOfBocCacheSet, ResultOfBocCacheSet, \
-    ParamsOfBocCacheUnpin, ParamsOfEncodeBoc, ResultOfEncodeBoc, \
-    ParamsOfGetCodeSalt, ResultOfGetCodeSalt, ParamsOfSetCodeSalt, \
-    ResultOfSetCodeSalt, ParamsOfDecodeTvc, ResultOfDecodeTvc, \
-    ParamsOfEncodeTvc, ResultOfEncodeTvc, ParamsOfGetCompilerVersion, \
-    ResultOfGetCompilerVersion, ParamsOfGetBocDepth, ResultOfGetBocDepth
+from tonclient.types import (
+    ParamsOfParse,
+    ResultOfParse,
+    ParamsOfParseShardstate,
+    ParamsOfGetBocHash,
+    ResultOfGetBocHash,
+    ParamsOfGetBlockchainConfig,
+    ResultOfGetBlockchainConfig,
+    ParamsOfGetCodeFromTvc,
+    ResultOfGetCodeFromTvc,
+    ParamsOfBocCacheGet,
+    ResultOfBocCacheGet,
+    ParamsOfBocCacheSet,
+    ResultOfBocCacheSet,
+    ParamsOfBocCacheUnpin,
+    ParamsOfEncodeBoc,
+    ResultOfEncodeBoc,
+    ParamsOfGetCodeSalt,
+    ResultOfGetCodeSalt,
+    ParamsOfSetCodeSalt,
+    ResultOfSetCodeSalt,
+    ParamsOfDecodeTvc,
+    ResultOfDecodeTvc,
+    ParamsOfEncodeTvc,
+    ResultOfEncodeTvc,
+    ParamsOfGetCompilerVersion,
+    ResultOfGetCompilerVersion,
+    ParamsOfGetBocDepth,
+    ResultOfGetBocDepth,
+    ParamsOfEncodeExternalInMessage,
+    ResultOfEncodeExternalInMessage,
+)
 
 
 class TonBoc(TonModule):
-    """ Free TON boc SDK API implementation """
+    """Free TON boc SDK API implementation"""
 
     def parse_message(
-            self, params: ParamsOfParse
+        self, params: ParamsOfParse
     ) -> Union[ResultOfParse, Awaitable[ResultOfParse]]:
         """
         Parses message boc into a JSON.
@@ -30,7 +53,7 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfParse, response=response)
 
     def parse_transaction(
-            self, params: ParamsOfParse
+        self, params: ParamsOfParse
     ) -> Union[ResultOfParse, Awaitable[ResultOfParse]]:
         """
         Parses transaction boc into a JSON.
@@ -43,7 +66,7 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfParse, response=response)
 
     def parse_account(
-            self, params: ParamsOfParse
+        self, params: ParamsOfParse
     ) -> Union[ResultOfParse, Awaitable[ResultOfParse]]:
         """
         Parses account boc into a JSON.
@@ -56,7 +79,7 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfParse, response=response)
 
     def parse_block(
-            self, params: ParamsOfParse
+        self, params: ParamsOfParse
     ) -> Union[ResultOfParse, Awaitable[ResultOfParse]]:
         """
         Parses block boc into a JSON.
@@ -69,7 +92,7 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfParse, response=response)
 
     def parse_shardstate(
-            self, params: ParamsOfParseShardstate
+        self, params: ParamsOfParseShardstate
     ) -> Union[ResultOfParse, Awaitable[ResultOfParse]]:
         """
         Parses shardstate boc into a JSON.
@@ -82,11 +105,8 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfParse, response=response)
 
     def get_boc_hash(
-            self, params: ParamsOfGetBocHash
-    ) -> Union[
-        ResultOfGetBocHash,
-        Awaitable[ResultOfGetBocHash]
-    ]:
+        self, params: ParamsOfGetBocHash
+    ) -> Union[ResultOfGetBocHash, Awaitable[ResultOfGetBocHash]]:
         """
         Calculates BOC root hash
 
@@ -97,11 +117,8 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfGetBocHash, response=response)
 
     def get_blockchain_config(
-            self, params: ParamsOfGetBlockchainConfig
-    ) -> Union[
-        ResultOfGetBlockchainConfig,
-        Awaitable[ResultOfGetBlockchainConfig]
-    ]:
+        self, params: ParamsOfGetBlockchainConfig
+    ) -> Union[ResultOfGetBlockchainConfig, Awaitable[ResultOfGetBlockchainConfig]]:
         """
         Extract blockchain configuration from key block and also from
         zero state
@@ -109,13 +126,11 @@ class TonBoc(TonModule):
         :param params: See `ParamsOfGetBlockchainConfig`
         :return: See `ResultOfGetBlockchainConfig`
         """
-        response = self.request(
-            method='boc.get_blockchain_config', **params.dict)
-        return self.response(
-            classname=ResultOfGetBlockchainConfig, response=response)
+        response = self.request(method='boc.get_blockchain_config', **params.dict)
+        return self.response(classname=ResultOfGetBlockchainConfig, response=response)
 
     def get_code_from_tvc(
-            self, params: ParamsOfGetCodeFromTvc
+        self, params: ParamsOfGetCodeFromTvc
     ) -> Union[ResultOfGetCodeFromTvc, Awaitable[ResultOfGetCodeFromTvc]]:
         """
         Extracts code from TVC contract image
@@ -124,11 +139,10 @@ class TonBoc(TonModule):
         :return: See `types.ResultOfGetCodeFromTvc`
         """
         response = self.request(method='boc.get_code_from_tvc', **params.dict)
-        return self.response(
-            classname=ResultOfGetCodeFromTvc, response=response)
+        return self.response(classname=ResultOfGetCodeFromTvc, response=response)
 
     def cache_get(
-            self, params: ParamsOfBocCacheGet
+        self, params: ParamsOfBocCacheGet
     ) -> Union[ResultOfBocCacheGet, Awaitable[ResultOfBocCacheGet]]:
         """
         Get BOC from cache
@@ -140,7 +154,7 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfBocCacheGet, response=response)
 
     def cache_set(
-            self, params: ParamsOfBocCacheSet
+        self, params: ParamsOfBocCacheSet
     ) -> Union[ResultOfBocCacheSet, Awaitable[ResultOfBocCacheSet]]:
         """
         Save BOC into cache
@@ -152,7 +166,7 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfBocCacheSet, response=response)
 
     def cache_unpin(
-            self, params: ParamsOfBocCacheUnpin
+        self, params: ParamsOfBocCacheUnpin
     ) -> Union[None, Awaitable[None]]:
         """
         Unpin BOCs with specified pin.
@@ -164,7 +178,7 @@ class TonBoc(TonModule):
         return self.request(method='boc.cache_unpin', **params.dict)
 
     def encode_boc(
-            self, params: ParamsOfEncodeBoc
+        self, params: ParamsOfEncodeBoc
     ) -> Union[ResultOfEncodeBoc, Awaitable[ResultOfEncodeBoc]]:
         """
         Encodes bag of cells (BOC) with builder operations.
@@ -179,7 +193,7 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfEncodeBoc, response=response)
 
     def get_code_salt(
-            self, params: ParamsOfGetCodeSalt
+        self, params: ParamsOfGetCodeSalt
     ) -> Union[ResultOfGetCodeSalt, Awaitable[ResultOfGetCodeSalt]]:
         """
         Returns the contract code's salt if it is present
@@ -191,7 +205,7 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfGetCodeSalt, response=response)
 
     def set_code_salt(
-            self, params: ParamsOfSetCodeSalt
+        self, params: ParamsOfSetCodeSalt
     ) -> Union[ResultOfSetCodeSalt, Awaitable[ResultOfSetCodeSalt]]:
         """
         Sets new salt to contract code.
@@ -204,7 +218,7 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfSetCodeSalt, response=response)
 
     def decode_tvc(
-            self, params: ParamsOfDecodeTvc
+        self, params: ParamsOfDecodeTvc
     ) -> Union[ResultOfDecodeTvc, Awaitable[ResultOfDecodeTvc]]:
         """
         Decodes tvc into code, data, libraries and special options
@@ -216,7 +230,7 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfDecodeTvc, response=response)
 
     def encode_tvc(
-            self, params: ParamsOfEncodeTvc
+        self, params: ParamsOfEncodeTvc
     ) -> Union[ResultOfEncodeTvc, Awaitable[ResultOfEncodeTvc]]:
         """
         Encodes tvc from code, data, libraries ans special options
@@ -229,24 +243,19 @@ class TonBoc(TonModule):
         return self.response(classname=ResultOfEncodeTvc, response=response)
 
     def get_compiler_version(
-            self, params: ParamsOfGetCompilerVersion
-    ) -> Union[
-        ResultOfGetCompilerVersion,
-        Awaitable[ResultOfGetCompilerVersion]
-    ]:
+        self, params: ParamsOfGetCompilerVersion
+    ) -> Union[ResultOfGetCompilerVersion, Awaitable[ResultOfGetCompilerVersion]]:
         """
         Returns the compiler version used to compile the code
 
         :param params: See `types.ParamsOfGetCompilerVersion`
         :return: See `types.ResultOfGetCompilerVersion`
         """
-        response = self.request(
-            method='boc.get_compiler_version', **params.dict)
-        return self.response(
-            classname=ResultOfGetCompilerVersion, response=response)
+        response = self.request(method='boc.get_compiler_version', **params.dict)
+        return self.response(classname=ResultOfGetCompilerVersion, response=response)
 
     def get_boc_depth(
-            self, params: ParamsOfGetBocDepth
+        self, params: ParamsOfGetBocDepth
     ) -> Union[ResultOfGetBocDepth, Awaitable[ResultOfGetBocDepth]]:
         """
         Calculates BOC depth
@@ -256,3 +265,20 @@ class TonBoc(TonModule):
         """
         response = self.request(method='boc.get_boc_depth', **params.dict)
         return self.response(classname=ResultOfGetBocDepth, response=response)
+
+    def encode_external_in_message(
+        self, params: ParamsOfEncodeExternalInMessage
+    ) -> Union[
+        ResultOfEncodeExternalInMessage, Awaitable[ResultOfEncodeExternalInMessage]
+    ]:
+        """
+        Encodes a message.
+        Allows to encode any external inbound message.
+
+        :params params: See `types.ParamsOfEncodeExternalInMessage`
+        :return: See `types.ResultOfEncodeExternalInMessage`
+        """
+        response = self.request(method='boc.encode_external_in_message', **params.dict)
+        return self.response(
+            classname=ResultOfEncodeExternalInMessage, response=response
+        )
